# remirepo spec file for php-pecl-parle
#
# SPDX-FileCopyrightText:  Copyright 2017-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#

%bcond_without      tests
%{?scl:%scl_package php-pecl-parle}

%global with_zts     0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name    parle
# After json
%global ini_name     40-%{pecl_name}.ini
%global sources      %{pecl_name}-%{version}
%global _configure   ../%{sources}/configure

Summary:        Parsing and lexing
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        0.8.5
Release:        3%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
# Extension is BSD, libraries are Boost
License:        BSD-2-Clause AND BSL-1.0
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{pecl_name}-%{version}.tgz

Patch0:         59.patch

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?dtsprefix}gcc-c++
BuildRequires:  %{?dtsprefix}libstdc++-devel
BuildRequires:  %{?scl_prefix}php-devel >= 7.4
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  %{?scl_prefix}php-json

# bundled libraries
Provides:       bundled(parsertl)
Provides:       bundled(lexertl)

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
Requires:       %{?scl_prefix}php-json%{?_isa}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}

Obsoletes:      %{name}-devel < %{version}


%description
With Parle, it is possible to implement lexing and parsing in PHP
while relying on features and principles of the parser/lexer
generator tools for C/C++.

Documentation: http://php.net/parle

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -qc
# Don't install/register tests
sed -e '/tests/s/role="test"/role="src"/'\
    -i package.xml

sed -e '/LICENSE/s/role="doc"/role="src"/;/licence/s/role="doc"/role="src"/' \
    -i package.xml
mv %{sources}/lib/parsertl14/include/parsertl/licence_1_0.txt %{sources}/LICENSE.lexert14
mv %{sources}/lib/lexertl14/include/lexertl/licence_1_0.txt   %{sources}/LICENSE.parsertl14

cd %{sources}
%patch -P0 -p1
# Sanity check, really often broken
extver=$(sed -n '/#define PHP_PARLE_VERSION/{s/.* "//;s/".*$//;p}' php_parle.h)
if test "x${extver}" != "x%{version}%{?prever:-%{prever}}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?prever:-%{prever}}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable '%{summary}' extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

peclbuild() {
%configure \
    --enable-parle \
    --with-php-config=$1

make %{?_smp_mflags}
}

cd %{sources}
%{__phpize}

cd ../NTS
peclbuild %{__phpconfig}

%if %{with_zts}
cd ../ZTS
peclbuild %{__ztsphpconfig}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
: Minimal load test for NTS extension
cd NTS
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite
make test "TESTS=--show-diff -q %{?_smp_mflags}"
%endif

%if %{with_zts}
cd ../ZTS
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite
make test "TESTS=--show-diff -q %{?_smp_mflags}"
%endif
%endif


%files
%license %{sources}/LICENSE*
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif

######### TODO : use --enable-parle-utf32 ?

%changelog
* Thu Jul 17 2025 Remi Collet <remi@remirepo.net> - 0.8.5-3
- add fix for PHP 8.5.0alpha2 using patch from
  https://github.com/weltling/parle/pull/59
- re-license spec file to CECILL-2.1

* Wed Aug 30 2023 Remi Collet <remi@remirepo.net> - 0.8.5-2
- rebuild for PHP 8.3.0RC1

* Sun Jul  2 2023 Remi Collet <remi@remirepo.net> - 0.8.5-1
- update to 0.8.5
- build out of sources tree

* Sun May 14 2023 Remi Collet <remi@remirepo.net> - 0.8.4-1
- update to 0.8.4
- raise dependency on PHP 7.4

* Sat Apr 16 2022 Remi Collet <remi@remirepo.net> - 0.8.3-1
- update to 0.8.3
- drop patch merged upstream

* Thu Sep  9 2021 Remi Collet <remi@remirepo.net> - 0.8.2-2
- add patch for PHP 8.1 from
  https://github.com/weltling/parle/pull/28

* Mon Jan 18 2021 Remi Collet <remi@remirepo.net> - 0.8.2-1
- update to 0.8.2
- drop patches merged upstream

* Fri Jan 15 2021 Remi Collet <remi@remirepo.net> - 0.8.1-9
- add patch for 8.0 from
  https://github.com/weltling/parle/pull/22

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.8.1-8
- rebuild for 7.4.0RC1

* Fri Aug 23 2019 Remi Collet <remi@remirepo.net> - 0.8.1-7
- add patch for 7.4 from
  https://github.com/weltling/parle/pull/17

* Tue Jun  4 2019 Remi Collet <remi@remirepo.net> - 0.8.1-6
- add upstream patch for 7.4

* Wed Dec 12 2018 Remi Collet <remi@remirepo.net> - 0.8.1-5
- cleanup for EL-8

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 0.8.1-4
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 0.8.1-3
- rebuild for 7.3.0alpha4 new ABI

* Mon Mar  5 2018 Remi Collet <remi@remirepo.net> - 0.8.1-1
- Update to 0.8.1

* Thu Mar  1 2018 Remi Collet <remi@remirepo.net> - 0.7.3-2
- add patch to fix build with gcc 8
  from https://github.com/weltling/parle/pull/13

* Sun Nov 12 2017 Remi Collet <remi@remirepo.net> - 0.7.3-1
- Update to 0.7.3

* Mon Oct 30 2017 Remi Collet <remi@remirepo.net> - 0.7.1-1
- Update to 0.7.1

* Mon Oct  2 2017 Remi Collet <remi@remirepo.net> - 0.7.0-1
- Update to 0.7.0

* Fri Sep 29 2017 Remi Collet <remi@remirepo.net> - 0.6.5-1
- Update to 0.6.5

* Tue Sep 26 2017 Remi Collet <remi@remirepo.net> - 0.6.4-1
- Update to 0.6.4

* Sat Sep 23 2017 Remi Collet <remi@remirepo.net> - 0.6.3-1
- Update to 0.6.3

* Wed Sep 20 2017 Remi Collet <remi@remirepo.net> - 0.6.2-1
- Update to 0.6.2

* Mon Sep 18 2017 Remi Collet <remi@remirepo.net> - 0.6.1-1
- Update to 0.6.1

* Sun Sep 17 2017 Remi Collet <remi@remirepo.net> - 0.6.0-1
- Update to 0.6.0

* Sat Sep  9 2017 Remi Collet <remi@remirepo.net> - 0.5.3-1
- Update to 0.5.3
- open https://github.com/weltling/parle/pull/8 - cxx extension

* Sat Sep  9 2017 Remi Collet <remi@remirepo.net> - 0.5.2-1
- Update to 0.5.2
- drop devel sub-package
- open https://github.com/weltling/parle/pull/7 - PHP 7.2 build error

* Sat Sep  9 2017 Remi Collet <remi@remirepo.net> - 0.5.1-1
- initial package, version 0.5.1 (alpha)
- open https://github.com/BenHanson/parsertl14/issues/1 license file
- open https://github.com/weltling/parle/pull/1 missing license file
- open https://github.com/weltling/parle/pull/2 fix roles
- open https://github.com/weltling/parle/issues/3 is header needed
